@@ -7,7 +7,7 @@ test_that("na values in input throws errors", {
   expect_error(SLOPE(matrix(3, 3, 3), c(NA, NA, 1)))
 })
 
-test_that("erroneous lambda ans alpha input throws errors", {
+test_that("erroneous lambda and alpha input throws errors", {
   x <- matrix(1, 3, 3)
   y <- double(3)
 
@@ -15,7 +15,6 @@ test_that("erroneous lambda ans alpha input throws errors", {
   expect_error(SLOPE(x, y, lambda = 1:3))
   expect_error(SLOPE(x, y, lambda = -c(1, 2, 3)))
   expect_error(SLOPE(x, y, alpha = -1))
-  expect_error(SLOPE(x, y, alpha = 1:2))
 })
 
 test_that("erroneous standardization settings throw", {
